@@ -22,7 +22,6 @@
 
 #include "frame.h"
 #include "akregatorpart_export.h"
-#include <QObject>
 
 namespace Akregator {
 class ArticleViewerWebEngineWidgetNg;
@@ -68,7 +67,7 @@ private Q_SLOTS:
     void slotWebPageMutedOrAudibleChanged(bool isAudioMuted, bool wasRecentlyAudible);
 private:
     void loadUrl(const QUrl &url);
-    Akregator::ArticleViewerWebEngineWidgetNg *mArticleViewerWidgetNg;
+    Akregator::ArticleViewerWebEngineWidgetNg *mArticleViewerWidgetNg = nullptr;
 };
 }
 
